
# Package "laeken"

# Estimation of Laeken indicators using synthetic EU-SILC data

# description of the EU-SILC survey:
# http://ec.europa.eu/eurostat/web/microdata/european-union-statistics-on-income-and-living-conditions

# load the library (necessary to install it in R the first time it is used)
library(laeken)

# load synthetic Austrian EU-SILC data
data(eusilc)
dim(eusilc)

# A data frame with 14827 observations on the following 28 variables:

# db030 integer; the household ID.
# hsize integer; the number of persons in the household.
# db040 factor; the federal state in which the household is located (levels Burgenland, Carinthia, Lower Austria, Salzburg, Styria, Tyrol, Upper Austria, Vienna and Vorarlberg).
# rb030 integer; the personal ID.
# age integer; the person’s age.
# rb090 factor; the person’s gender (levels male and female).
# pl030 factor;the person’s economic status(levels1 = working full time, 2 = working part time, 3 = unemployed, 4 = pupil, student, further training or unpaid work experience or in compulsory military or community service, 5 = in retirement or early retirement or has given up business, 6 = permanently disabled or/and unfit to work or other inactive person, 7 = fulfilling domestic tasks and care responsibilities).
# pb220a factor; the person’s citizenship (levels AT, EU and Other). 
# py010n numeric; employee cash or near cash income (net).
# py050n numeric; cash benefits or losses from self-employment (net). 
# py090n numeric; unemployment benefits (net).
# py100n numeric; old-age benefits (net).
# py110n numeric; survivor’s benefits (net).
# py120n numeric; sickness benefits (net).
# py130n numeric; disability benefits (net).
# py140n numeric; education-related allowances (net).
# hy040n numeric; income from rental of a property or land (net). hy050n numeric; family/children related allowances (net). hy070n numeric; housing allowances (net).
# hy080n numeric; regular inter-household cash transfer received (net).
# hy090n numeric; interest, dividends, profit from capital investments in unincorporated business (net).
# hy110n numeric; income received by people aged under 16 (net).
# hy130n numeric; regular inter-household cash transfer paid (net).
# hy145n numeric; repayments/receipts for tax adjustment (net).
# eqSS numeric; the equivalized household size according to the modified OECD scale
# eqIncome numeric; a slightly simplified version of the equivalized household income
# db090 numeric; the household sample weights.
# rb050 numeric; the personal sample weights.


# descriptive statistics of all the available data
summary(eusilc)

# print the first five records
eusilc[1:5,]


# count the number of individuals sampled in each federal state
library(plyr)
count(eusilc$rb030, 'eusilc$db040')
# numer of individuals in the population
sum(eusilc$rb050)
# numer of individuals in the population, per federal state
tapply(eusilc$rb050,eusilc$db040,sum)

# taking only the first individual from each household
eusilc2 <- eusilc[!duplicated(eusilc$db030),]
# count the number of households sampled in each federal state
count(eusilc2$rb030, 'eusilc2$db040')
# numer of households in the population
sum(eusilc2$db090)
# numer of households in the population, per federal state
tapply(eusilc2$db090,eusilc2$db040,sum)



########### Estimation of Laeken indicators


# We want to compute the at-risk-of-poverty rate and the relative median at-risk-of-poverty gap as defined by Eurostat in the Laeken indicators

# The variable eqIncome contains for each individual the household equivalized total net income, calculated as the household total net income divided by the equivalised household size
# the equivalence scale is the modified OECD scale

# poverty threshold: is equal to the 60% of the national median equivalised income
arpt(eusilc$eqIncome, weights = eusilc$rb050)
 
# can also be obtained as:
weightedMedian(eusilc$eqIncome, eusilc$rb050)*0.6


# AT-RISK-OF-POVERTY RATE

# at-risk-of-poverty rate: national level
arpr(eusilc$eqIncome, weights = eusilc$rb050, design =eusicl$db040)
     
# at-risk-of-poverty rate: federal states level (NUTS 2)
arpr(eusilc$eqIncome, weights = eusilc$rb050, design =eusilc$db040, breakdown = eusilc$db040)

# computing confidence intervals: national level
a <- arpr(eusilc$eqIncome, weights = eusilc$rb050, design =eusicl$db040) 
bootVar(inc=eusilc$eqIncome, weights = eusilc$rb050, design =eusilc$db040, indicator=a, R=1000, bootType="naive", ciType="perc")

# computing confidence intervals: federal states level (NUTS 2)
a.states <- arpr(eusilc$eqIncome, weights = eusilc$rb050, design=eusilc$db040, breakdown=eusilc$db040) 
bootVar(inc=eusilc$eqIncome, weights = eusilc$rb050, design =eusilc$db040, indicator=a.states, breakdown=eusilc$db040, R=1000, bootType="naive", ciType="perc")




# RELATIVE MEDIAN AT-RISK-OF-POVERTY GAP

# relative median at-risk-of-poverty gap: national level
rmpg(eusilc$eqIncome, weights = eusilc$rb050, design =eusilc$db040)

# relative median at-risk-of-poverty gap: federal states level (NUTS 2)
rmpg(eusilc$eqIncome, weights = eusilc$rb050, design =eusilc$db040, breakdown = eusilc$db040)
  
# computing confidence intervals: national level
pg <- rmpg(eusilc$eqIncome, weights = eusilc$rb050, design =eusicl$db040) 
bootVar(inc=eusilc$eqIncome, weights = eusilc$rb050, design =eusilc$db040, indicator=pg, R=1000, bootType="naive", ciType="perc")

# computing confidence intervals: federal states level (NUTS 2)
pg.states <- rmpg(eusilc$eqIncome, weights = eusilc$rb050, design=eusilc$db040, breakdown=eusilc$db040) 
bootVar(inc=eusilc$eqIncome, weights = eusilc$rb050, design =eusilc$db040, indicator=pg.states, breakdown=eusilc$db040, R=1000, bootType="naive", ciType="perc")



# QUINTILE SHARE RATIO

# quintile share ratio: national level
qsr(eusilc$eqIncome, weights = eusilc$rb050, design =eusilc$db040)

# quintile share ratio: federal states level (NUTS 2)
qsr(eusilc$eqIncome, weights = eusilc$rb050, , design =eusilc$db040, breakdown = eusilc$db040)

# computing confidence intervals: national level
q<-qsr(eusilc$eqIncome, weights = eusilc$rb050, design =eusilc$db040)
bootVar(inc=eusilc$eqIncome, weights = eusilc$rb050, design =eusilc$db040, indicator=q, R=1000, bootType="naive", ciType="perc")

# computing confidence intervals: federal states level (NUTS 2)
q.states <- qsr(eusilc$eqIncome, weights = eusilc$rb050, , design =eusilc$db040, breakdown = eusilc$db040)
bootVar(inc=eusilc$eqIncome, weights = eusilc$rb050, design =eusilc$db040, indicator=q.states, breakdown=eusilc$db040, R=1000, bootType="naive", ciType="perc")


